@@ -3,17 +3,17 @@ use syntree::TreeBuilder;
 fn main() -> Result<(), Box<dyn std::error::Error>> {
     let mut tree = TreeBuilder::new();
 
-    tree.open("root1");
+    tree.open("root1")?;
 
-    tree.open("child1");
+    tree.open("child1")?;
     tree.close()?;
 
-    tree.open("child2");
+    tree.open("child2")?;
     tree.close()?;
 
     tree.close()?;
 
-    tree.open("root2");
+    tree.open("root2")?;
     tree.close()?;
 
     let tree = tree.build()?;
