@@ -1,6 +1,4 @@
-use crate::links::Links;
-use crate::non_max::NonMaxUsize;
-use crate::{Event, Node, WalkEvents, WithoutTokens};
+use crate::{Event, Node, SkipTokens, WalkEvents};
 
 /// An iterator that walks over the entire tree, visiting every node exactly
 /// once.
@@ -46,9 +44,10 @@ pub struct Walk<'a, T> {
 }
 
 impl<'a, T> Walk<'a, T> {
-    pub(crate) fn new(tree: &'a [Links<T>], start: Option<NonMaxUsize>) -> Self {
+    /// Construct a new walk.
+    pub(crate) const fn new(node: Option<Node<'a, T>>) -> Self {
         Self {
-            iter: WalkEvents::new(tree, start),
+            iter: WalkEvents::new(node),
         }
     }
 
@@ -59,12 +58,12 @@ impl<'a, T> Walk<'a, T> {
         WithDepths { iter: self }
     }
 
-    /// Construct a [WithoutTokens] iterator from the remainder of this
+    /// Construct a [SkipTokens] iterator from the remainder of this
     /// iterator. This filters out [Kind::Token][crate::Kind::Token] elements.
     ///
-    /// See [WithoutTokens] for documentation.
-    pub fn without_tokens(self) -> WithoutTokens<Self> {
-        WithoutTokens::new(self)
+    /// See [SkipTokens] for documentation.
+    pub fn skip_tokens(self) -> SkipTokens<Self> {
+        SkipTokens::new(self)
     }
 
     /// Get the next node including the depth which it is located at. This
